var indexSectionsWithContent =
{
  0: "01abcdefghilmopstuvw",
  1: "l",
  2: "l",
  3: "l",
  4: "abcdefghilmopstuw",
  5: "fl",
  6: "l",
  7: "l",
  8: "abcdfhilmopsuv",
  9: "cdil"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "groups",
  9: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Modules",
  9: "Pages"
};

